"""Store package metadata."""

__author__ = 'Kieran Colford'
__license__ = 'GPLv3+'
__copyright__ = 'Copyright (C) 2015 Kieran Colford'
__credits__ = """Mark Petrick, for the support that inspired this project.
"""
__version__ = '1.0.1'
